ExtraMsg class abstract

作者:李佳奇 日期:2022/5/2 备注:binding 附加上报信息接口

Constructors

ExtraMsg()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getExtraMsg() → String
获取额外相关信息
isValid() → bool
额外信息是否有效
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited