ChannelModel class

Implemented types

Constructors

ChannelModel({required String channelName, required String? methodName, required dynamic arguments, required int type})
ChannelModel.error({required String channelName, String? methodName = '', dynamic arguments = '', int type = -1})

Properties

arguments → dynamic
方法附带参数
final
channelName → String
channel 名
final
hashCode → int
The hash code for this object.
no setterinherited
isAbnormal → bool
异常记录包
no setteroverride
methodCodec ↔ MethodCodec?
getter/setter pair
methodName → String?
方法名
final
receiveTimestamp ↔ int
结果接收时间
getter/setter pair
resStr → String
no setter
results ↔ dynamic
返回结果
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sendTimestamp → int
方法调用时间
final
type → int
channel类型
final

Methods

getPackage() → Map<String, String>
记录包
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

TYPE_DEV_RECEIVE → const int
TYPE_DEV_SEND → const int
消息类型
TYPE_SYSTEM_RECEIVE → const int
TYPE_SYSTEM_SEND → const int